@@ -6,7 +6,7 @@ import re
 
 def get_decisions(year, init_no=0, last_no=999999, keyword='içtihat'):
     # path of chromedriver.exe
-    driver_path = "emsal/chromedriver"
+    driver_path = "../../chromedriver"
 
     # define driver
     driver = webdriver.Chrome(executable_path=driver_path)
@@ -99,5 +99,4 @@ def get_decisions(year, init_no=0, last_no=999999, keyword='içtihat'):
         # go to next decision
         time.sleep(3)
         next_btn = driver.find_element_by_id('aramaForm:sonrakiEvrakLabel')
-        next_btn.click()
-
+        next_btn.click()
\ No newline at end of file
